@@ -1,10 +1,11 @@
 package Benchmark::Perl::Formance;
-# git description: v0.38-6-g08c42de
+# git description: v0.39-4-gb114950
 
 BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Benchmark::Perl::Formance::VERSION = '0.39';
+# ABSTRACT: Perl 5 performance benchmarking framework
+$Benchmark::Perl::Formance::VERSION = '0.40';
 use 5.008;
 
 use warnings;
@@ -532,6 +533,7 @@ sub run {
         my $help           = 0;
         my $showconfig     = 0;
         my $outstyle       = "summary";
+        my $outfile        = "";
         my $platforminfo   = 0;
         my $codespeed      = 0;
         my $tapper         = 0;
@@ -560,6 +562,7 @@ sub run {
                              "plugins=s"        => \$plugins,
                              "verbose|v+"       => \$verbose,
                              "outstyle=s"       => \$outstyle,
+                             "outfile=s"        => \$outfile,
                              "fastmode"         => \$fastmode,
                              "version"          => \$version,
                              "useforks"         => \$useforks,
@@ -582,6 +585,7 @@ sub run {
                             help           => $help,
                             quiet          => $quiet,
                             verbose        => $verbose,
+                            outfile        => $outfile,
                             outstyle       => $outstyle,
                             fastmode       => $fastmode,
                             useforks       => $useforks,
@@ -677,7 +681,7 @@ sub print_outstyle_yaml
         my ($self, $RESULTS) = @_;
 
         require YAML;
-        print YAML::Dump($RESULTS);
+        return YAML::Dump($RESULTS);
 }
 
 sub print_outstyle_json
@@ -685,7 +689,7 @@ sub print_outstyle_json
         my ($self, $RESULTS) = @_;
 
         require JSON;
-        print JSON->new->allow_nonref->pretty->encode( $RESULTS );
+        return JSON->new->allow_nonref->pretty->encode( $RESULTS );
 }
 
 sub print_outstyle_yamlish
@@ -702,7 +706,7 @@ sub print_outstyle_yamlish
 
         my $tapdescription = $self->{options}{tapdescription};
         $output = "ok $tapdescription\n".$output if $tapdescription;
-        print $output;
+        return $output;
 }
 
 sub find_interesting_result_paths
@@ -732,6 +736,8 @@ sub print_outstyle_summary
 {
         my ($self, $RESULTS) = @_;
 
+        my $output = '';
+
         my @run_plugins = $self->find_interesting_result_paths($RESULTS);
         my $len = max map { length } @run_plugins;
         $len   += 1+length($metric_prefix);
@@ -740,8 +746,9 @@ sub print_outstyle_summary
                 no strict 'refs'; ## no critic
                 my @resultkeys = split(/\./);
                 my ($res) = dpath("/results/".join("/", map { qq("$_") } @resultkeys)."/Benchmark/*[0]")->match($RESULTS);
-                print sprintf("%-${len}s : %f\n", join(".", $metric_prefix, $_), ($res || 0));
+                $output .= sprintf("%-${len}s : %f\n", join(".", $metric_prefix, $_), ($res || 0));
         }
+        return $output;
 }
 
 sub print_results
@@ -753,7 +760,21 @@ sub print_results
         $outstyle = "summary" unless $outstyle =~ qr/^(summary|yaml|yamlish|json)$/;
         my $sub = "print_outstyle_$outstyle";
 
-        $self->$sub($RESULTS);
+        my $output = $self->$sub($RESULTS);
+
+        if (my $outfile = $self->{options}{outfile})
+        {
+                open my $OUTFILE, ">", $outfile or do {
+                        warn "Can not open $outfile. Printing to STDOUT.\n";
+                        print $output;
+                };
+                print $OUTFILE $output;
+                close $OUTFILE;
+        }
+        else
+        {
+                print $output;
+        }
 }
 
 1;
@@ -766,11 +787,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance
-
-=head1 NAME
-
-Benchmark::Perl::Formance - PerlFormance - Benchmark Suite
+Benchmark::Perl::Formance - Perl 5 performance benchmarking framework
 
 =head1 ABOUT
 
