@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Incubator;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Incubator::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Incubator - everchanging benchmark experiments
 
 use strict;
 use warnings;
@@ -48,16 +49,13 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Incubator
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Incubator - Incubator plugin for benchmark experiments
+Benchmark::Perl::Formance::Plugin::Incubator - benchmark plugin - Incubator - everchanging benchmark experiments
 
 =head1 ABOUT
 
 This is a B<free style> plugin where I collect ideas. Although it
-might contain interesting code you should never rely on this plugin.
+might contain interesting code you should never rely on this plugin as
+it will continuously change.
 
 =head1 AUTHOR
 
