@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::PerlCritic;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::PerlCritic::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - PerlCritic - Run Perl::Critic on itself
 
 use strict;
 use warnings;
@@ -116,17 +117,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::PerlCritic
-
-=head1 SYNOPSIS
-
-Run it as any other plugin.
-
-  $ perl-formance --plugins=PerlCritic
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::PerlCritic - Run Perl::Critic on itself
+Benchmark::Perl::Formance::Plugin::PerlCritic - benchmark plugin - PerlCritic - Run Perl::Critic on itself
 
 =head1 AUTHOR
 
