@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Rx;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Rx::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Rx - Stress regular expressions
 
 # Regexes
 
@@ -126,11 +127,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Rx
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Rx - Stress regular expressions
+Benchmark::Perl::Formance::Plugin::Rx - benchmark plugin - Rx - Stress regular expressions
 
 =head1 AUTHOR
 
