@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::nbody;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::nbody::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::nbody - Language shootout plugin: nbody
 
 # COMMAND LINE:
 # /usr/bin/perl nbody.perl 50000000
@@ -160,16 +161,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::nbody
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::nbody - Language shootout plugin: nbody
-
-=head1 ABOUT
-
-This plugin does some runs the "nbody" benchmark from the Language
-Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::nbody - benchmark plugin - Shootout::nbody - Language shootout plugin: nbody
 
 =head1 AUTHOR
 
