@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::pidigits;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::pidigits::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::pidigits - Language shootout plugin: pidigits
 
 # The Computer Language Benchmarks Game
 #   http://shootout.alioth.debian.org/
@@ -98,16 +99,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::pidigits
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::pidigits - Language shootout plugin: pidigits
-
-=head1 ABOUT
-
-This plugin does some runs the "pidigits" benchmark from the Language
-Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::pidigits - benchmark plugin - Shootout::pidigits - Language shootout plugin: pidigits
 
 =head1 AUTHOR
 
