@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::spectralnorm;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::spectralnorm::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::spectralnorm - Language shootout plugin: spectralnorm
 
 # COMMAND LINE:
 # /usr/bin/perl spectralnorm.perl-3.perl 5500
@@ -172,16 +173,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::spectralnorm
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::spectralnorm - Language shootout plugin: spectralnorm
-
-=head1 ABOUT
-
-This plugin does some runs the "spectralnorm" benchmark from the
-Language Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::spectralnorm - benchmark plugin - Shootout::spectralnorm - Language shootout plugin: spectralnorm
 
 =head1 AUTHOR
 
