@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Threads;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Threads::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Threads - Stress threading
 
 # Create threads to evaluate Fibonacci numbers
 
@@ -88,7 +89,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Threads
+Benchmark::Perl::Formance::Plugin::Threads - benchmark plugin - Threads - Stress threading
 
 =head1 SYNOPSIS
 
@@ -97,10 +98,6 @@ maximally be started. Default is 100.
 
   $ perl-formance --plugins=Threads -DThreads_threadcount=64
 
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Threads - Stress threading
-
 =head1 BUGS
 
 Too naive. Really.
